EEC448 SEED PHRASE PRIVATE_KEY SEED BYTES = 57 PRIVATE_KEY SEED BOOLEAN UNITS = 57 * 8 = 456 WORD LISTS: https://github.com/bitcoin/bips/blob/master/bip-0039/bip-0039-wordlists.md 2048 WORD DICTIONARY: 2 ** 11 = 2048 BITS BOOLEAN UNITS = 11 WORDS NECESSARY = 456 / 11 -> 41.45 -> 42 WORDS 4092 WORD DICTIONARY: 2 ** 12 = 4096 BITS BOOLEAN UNITS = 12 WORDS NECESSARY = 456 / 12 -> 38.0 -> 38 WORDS 8184 WORD DICTIONARY: 2 ** 12 = 8184 BITS BOOLEAN UNITS = 13 WORDS NECESSARY = 456 / 13 -> 35.07692307692308 -> 36 WORDS EXAMPLE [ ] NEED TO SEARCH FOR DUPLICATES DICTIONARY 1: ENGLISH DICTIONARY 2: FRENCH try: assert (len (seed) == 114) except Exception: # # WORD LIST: https://github.com/bitcoin/bips/blob/master/bip-0039.mediawiki # # EACH WORD IS: # 2 ** 11 = 2048 BITS # # 11 BOOLEAN UNITS # # # SEED BOOLEAN UNITS: # 57 BYTES = (2 ** 8) * 57 # # 8 * 57 = 456 # # # 11 BOOLEAN UNIT WORDS NECESSARY: # # 456 / 11 -> 41.45 -> 42 WORDS # # # 1 BYTE = 2 ** 8 = 256 BITS # # 2 BYTES = # print ("Seed must be 57 bytes") exit ()